Module: OmniAuth::Identity::Model::InstancePersistedApi
- Defined in:
- lib/omniauth/identity/model.rb
Overview
Provides a persisted? method for models that don't have one.
Instance Method Summary collapse
-
#persisted? ⇒ true, false
abstract
Checks if the Identity object is persisted in the ORM.
Instance Method Details
#persisted? ⇒ true, false
This method is abstract.
Checks if the Identity object is persisted in the ORM. Default raises an error. Override as needed per ORM.
158 159 160 |
# File 'lib/omniauth/identity/model.rb', line 158 def persisted? raise NotImplementedError end |